<?php
add_action('init', 'ard_cpt_init');

/**
 */
function ard_rewrite_flush()
{
    ard_cpt_init();
    flush_rewrite_rules();
}

/**
 * Доктора
 */
function ard_cpt_init()
{
    register_post_type("ard-donate", [
        "label" => "Донаты",
        "labels" => [
            "singular_name" => "Донат",
            "add_new" => "Добавить цель",
            "add_new_item" => "Добавить цель",
            "edit_item" => "Редактировать",
            'featured_image' => "Иконка доната",
            'set_featured_image' => "Установить иконку",
            'remove_featured_image' => "Удалить иконку",
            'use_featured_image' => "Использовать как иконку"
        ],
        "public" => true,
        "show_in_rest" => false,
        "menu_position" => 30,
        "menu_icon" => "dashicons-schedule",
        "capability_type" => "post",
        "supports" => [
            "title",
            "page-attributes",
            "editor",
            "thumbnail",
            "excerpt"
        ],
        "has_archive" => true,
        "rewrite" => [
            "slug" => "donats"
        ]
    ]);
}

add_action('cmb2_admin_init', 'ard_metaboxes');

function ard_metaboxes()
{
    $ma = new_cmb2_box(array(
        'id' => 'ard_donate_details',
        'title' => "Сведения о сборе",
        'object_types' => [
            "ard-donate"
        ],
        'context' => 'normal',
        'priority' => 'high',
        'show_names' => true
    ));

    $ma->add_field([
        "name" => "Целевая сумма",
        'id' => "target",
        "type" => "text_small"
    ]);

    $ma->add_field([
        "name" => "Рекомендуемая сумма взноса",
        'id' => "payment",
        "type" => "text_small"
    ]);

    $ma->add_field([
        "name" => "Сбор активен",
        'id' => "active",
        "type" => "checkbox"
    ]);

    $ma2 = new_cmb2_box(array(
        'id' => 'ard_donate_details2',
        'title' => "Процесс сбора",
        'object_types' => [
            "ard-donate"
        ],
        'context' => 'normal',
        'priority' => 'high',
        'show_names' => true
    ));

    $ma2->add_field([
        "name" => "Собрано средств",
        'id' => "summ",
        "type" => "text_small"
    ]);

    $ma2->add_field([
        "name" => "Вложено из фонда",
        'id' => "summ_fond",
        "type" => "text_small"
    ]);

    $ma2->add_field([
        "name" => "Потрачено средств",
        'id' => "debet",
        "type" => "text_small"
    ]);

    $ma2->add_field([
        "name" => "Подтверждения расходов",
        'id' => "debet_album",
        "type" => "file_list"
    ]);

    $ma3 = new_cmb2_box(array(
        'id' => 'ard_donate_details3',
        'title' => "Итог",
        'object_types' => [
            "ard-donate"
        ],
        'context' => 'normal',
        'priority' => 'high',
        'show_names' => true
    ));

    $ma3->add_field([
        "name" => "Описание результата",
        'id' => "final_text",
        "type" => "wysiwyg"
    ]);
}

/*
 * колонки
 *
 */

add_filter('manage_ard-donate_posts_columns', 'ard_custom_columns');
add_action('manage_ard-donate_posts_custom_column', 'ard_custom_column_text', 10, 2);

function ard_custom_columns($columns)
{
    $columns['ard-active'] = "Статус";
    $columns['ard-target'] = "Цель";
    $columns['ard-fond'] = "Из фонда";
    $columns['ard-get'] = "Собрано";
    $columns['ard-balance'] = "Осталось собрать";
    $columns['ard-payd'] = "Потрачено";
    $columns['ard-have-check'] = "Чеки";
    $columns['ard-have-result'] = "Результат";

    unset($columns['date']);

    return $columns;
}

function ard_custom_column_text($column, $post_id)
{
    switch ($column) {
        case 'ard-active':
            $s = get_post_meta($post_id, "active", true);
            if ($s=="on")
                $s="в работе";
            else
                $s="остановлен";
            echo sprintf('<span class="ard-summ">%s</span>', $s);
            break;
        
        case 'ard-target':
            $s = get_post_meta($post_id, "target", true);
            echo sprintf('<span class="ard-summ">%s</span>', $s);
            break;
        
        case 'ard-get':
            $s = get_post_meta($post_id, "summ", true);
            echo sprintf('<span class="ard-summ">%s</span>', $s);
            break;

        case 'ard-fond':
            $s = get_post_meta($post_id, "summ_fond", true);
            echo sprintf('<span class="ard-summ">%s</span>', $s);
            break;

        case 'ard-payd':
            $s = get_post_meta($post_id, "debet", true);
            echo sprintf('<span class="ard-summ">%s</span>', $s);
            break;
        
        case 'ard-have-check':
            $s = get_post_meta($post_id, "debet_album", true);
            if (isset($s) && is_array($s) && (count($s)>0))
                $s="приложены";
            echo sprintf('<span class="ard-summ">%s</span>', $s);
            break;
        
        case 'ard-have-result':
            $f = get_post_meta($post_id, "final_album", true);
            $t = get_post_meta($post_id, "final_text", true);
            $s=[];
            if (isset($f) && is_array($f) && (count($f)>0))
                $s[]="загружены фото";
            if (isset($t) && (trim($t)!=""))
                $s[]="текстовое описание";
            
            $s=implode(", ", $s);
            echo sprintf('<span class="ard-summ">%s</span>', $s);
            break;
        
        case 'ard-balance':
            $s1 = get_post_meta($post_id, "target", true);
            $s2 = get_post_meta($post_id, "summ", true);
            $sf = get_post_meta($post_id, "summ_fond", true);
            $s="-";
            if (isset($s2) && isset($s2)){
                $s=intval($s1)-intval($s2);
                if (isset($sf))
                    $s=$s-intval($sf);
                
            }
            echo sprintf('<span class="ard-summ">%s</span>', $s);
            break;
    }
}
















